create table obcan(
	rc VARCHAR2(10) PRIMARY KEY, 
	jmeno VARCHAR2(15) NOT NULL,
	prijmeni VARCHAR2(20) NOT NULL,
	rod_prijmeni VARCHAR2(20) NOT NULL,
	pohlavi NUMBER(1) NOT NULL,
	narodnost VARCHAR2(20) NOT NULL,
	pojistovna NUMBER(3) NOT NULL,
	rod_stav CHAR(9) CHECK (rod_stav IN ('Svobodny','Zenaty','Vdovec','Rozvedeny','Svobodna','Vdana','Vdova','Rozvedena')) NOT NULL,
	datum_smrti DATE,
	je_vojak NUMBER(1) NOT NULL,
	je_zamestnanec NUMBER(1) NOT NULL,
	je_duchodce NUMBER(1) NOT NULL
	);

create table bydliste(
	id_bydliste NUMBER(8) PRIMARY KEY, 
	ulice VARCHAR2(20) NOT NULL,
	mesto VARCHAR2(20) NOT NULL,
	psc NUMBER(5) NOT NULL,
	okres VARCHAR2(20) NOT NULL,
	cislo_popisne VARCHAR2(10) NOT NULL
	);


create table bydleni(
	id_bydliste NUMBER(8) NOT NULL, 
	FOREIGN KEY (id_bydliste) REFERENCES bydliste,
	rc VARCHAR2(10) NOT NULL,
	FOREIGN KEY (rc) REFERENCES obcan,
	bydli_od DATE NOT NULL,
	PRIMARY KEY (id_bydliste, rc, bydli_od),
	bydli_do DATE,
	cislo_bytu NUMBER(3) NOT NULL
	);
	
create table rodina(
	id_rodiny NUMBER(9) NOT NULL, 
	rc_otce VARCHAR2(10), 
	rc_matky VARCHAR2(10), 
	rc_potomka VARCHAR2(10) UNIQUE NOT NULL,
	PRIMARY KEY (id_rodiny)    
	);


create table vojak(
	vojenske_cislo NUMBER(9) PRIMARY KEY, 
	rc VARCHAR2(10) NOT NULL, 
	FOREIGN KEY (rc) REFERENCES obcan,
	hodnost VARCHAR2(20) NOT NULL,
	zarazeni VARCHAR2(20)
	);

create table utvar(
	cislo_utvaru NUMBER(5) PRIMARY KEY, 
	jmeno_utvaru VARCHAR2(30) NOT NULL,
	popis_utvaru VARCHAR2(60) NOT NULL,
	rc_velitele VARCHAR2(10), 
	FOREIGN KEY (rc_velitele) REFERENCES obcan
	);
	
create table slozka(
	vojenske_cislo NUMBER(9) NOT NULL, 
	FOREIGN KEY (vojenske_cislo) REFERENCES vojak,
	cislo_utvaru NUMBER(5) NOT NULL, 
	FOREIGN KEY (cislo_utvaru) REFERENCES utvar,
	datum_nastupu DATE NOT NULL,
	PRIMARY KEY (vojenske_cislo, cislo_utvaru, datum_nastupu), 
	datum_vystupu DATE
	);
	
create table manzelstvi(
	rc_manzela VARCHAR2(10) NOT NULL, 
	FOREIGN KEY (rc_manzela) REFERENCES obcan,
	rc_manzelky VARCHAR2(10) NOT NULL, 
	FOREIGN KEY (rc_manzelky) REFERENCES obcan,
	datum_svatby DATE NOT NULL,
	datum_rozchodu DATE,
	duvod_rozchodu CHAR(15) CHECK (duvod_rozchodu IN ('Smrt manzela','Smrt manzelky','Rozvod')),
	PRIMARY KEY (rc_manzela, rc_manzelky, datum_svatby)    
	);

create table duchod(
	rc_duchodce VARCHAR2(10) PRIMARY KEY, 
	FOREIGN KEY (rc_duchodce) REFERENCES obcan,
	ma_inv_duchod NUMBER(1) NOT NULL, 
	ma_star_duchod NUMBER(1) NOT NULL, 
	vyplata_duchodu NUMBER(5) 
	);
	
create table invalidita(
	kategorie_invalidity NUMBER(5) PRIMARY KEY,
	popis_poostizeni VARCHAR2(50) NOT NULL,
	tabulkova_hodnota NUMBER(5) NOT NULL
	);

create table invalidni_duchod(
	rc_duchodce VARCHAR2(10) NOT NULL, 
	FOREIGN KEY (rc_duchodce) REFERENCES obcan,
	kategorie_invalidity NUMBER(5) NOT NULL,
	FOREIGN KEY (kategorie_invalidity) REFERENCES invalidita,
	inv_od DATE NOT NULL,
	inv_do DATE,
	PRIMARY KEY (rc_duchodce, kategorie_invalidity, inv_od)    
	);

create table starobni_duchod(
	rc_duchodce VARCHAR2(10) PRIMARY KEY, 
	FOREIGN KEY (rc_duchodce) REFERENCES obcan,
	odprac_roky NUMBER(2) NOT NULL,
	stanovene_roky NUMBER(2) NOT NULL,
	celkovy_prijem NUMBER(10) NOT NULL
	);

create table typy_firem(
	typ_firmy NUMBER(2) PRIMARY KEY,
	nazev_typu VARCHAR2(20) NOT NULL,
	min_jmeni NUMBER(9)
	);

--upraveno not null u jednatele
create table firma(
	ico NUMBER(8) PRIMARY KEY,
	nazev_firmy VARCHAR2(40) NOT NULL,
	sidlo VARCHAR2(40) NOT NULL,
	typ_firmy NUMBER(2) NOT NULL,
	FOREIGN KEY (typ_firmy) REFERENCES typy_firem,
	jednatel VARCHAR2(10), 
	FOREIGN KEY (jednatel) REFERENCES obcan,
	zakl_jmeni NUMBER(9)
	);

create table zamestnanec(
	id_zamestnance NUMBER(9) PRIMARY KEY, 
	rc_zamestnance VARCHAR2(10) NOT NULL, 
	FOREIGN KEY (rc_zamestnance) REFERENCES obcan,
	ico_hpp NUMBER(8),
	FOREIGN KEY (ico_hpp) REFERENCES firma
	);


create table pracovni_pomer(
	id_pp NUMBER(8) PRIMARY KEY,
	id_zamestnance NUMBER(9) NOT NULL,
	FOREIGN KEY (id_zamestnance) REFERENCES zamestnanec,
	ico_zamestnavatele NUMBER(8) NOT NULL,
	FOREIGN KEY (ico_zamestnavatele) REFERENCES firma,
	typ_pomeru NUMBER(1) NOT NULL,
	popis_prace VARCHAR2(40),
	pracoval_od DATE NOT NULL,
	pracoval_do DATE
	);
										

create table platby(
	id_pp NUMBER(8) NOT NULL,
	FOREIGN KEY (id_pp) REFERENCES pracovni_pomer,
	rok  NUMBER(4) NOT NULL,
	suma NUMBER(10) NOT NULL,
	PRIMARY KEY (id_pp, rok)    
	);


