CREATE OR REPLACE TRIGGER tr_obcan_del
BEFORE DELETE ON obcan FOR EACH ROW 
BEGIN
	delete from bydleni where bydleni.rc = :old.rc;
	delete from vojak where vojak.rc = :old.rc;
	update utvar set utvar.rc_velitele = null 
		where rc_velitele = :old.rc;
	delete from rodina where rodina.rc_potomka = :old.rc;
	update rodina set rc_matky = null where rodina.rc_matky = :old.rc AND
		rodina.rc_otce is not null;
	update rodina set rc_otce = null where rodina.rc_otce = :old.rc AND
		rodina.rc_matky is not null;
	delete from rodina where rodina.rc_otce = :old.rc 
		OR rodina.rc_matky = :old.rc;
	delete from manzelstvi where manzelstvi.rc_manzela = :old.rc 
		OR manzelstvi.rc_manzelky = :old.rc;
	delete from duchod where duchod.rc_duchodce = :old.rc;
	delete from invalidni_duchod 
		where invalidni_duchod.rc_duchodce = :old.rc;
	delete from invalidni_duchod 
		where invalidni_duchod.rc_duchodce = :old.rc;
	delete from zamestnanec where zamestnanec.rc_zamestnance = :old.rc;
END;
/

CREATE OR REPLACE TRIGGER tr_obcan_post_up
AFTER UPDATE ON obcan FOR EACH ROW 
BEGIN
   IF not :old.rc = :new.rc THEN
	update bydleni set bydleni.rc = :new.rc where bydleni.rc = '0';
	update vojak set vojak.rc = :new.rc where vojak.rc = '0';
	update utvar set utvar.rc_velitele = :new.rc 
		where rc_velitele = '0';
	update rodina set rodina.rc_potomka = :new.rc 
		where rodina.rc_potomka = '0';
	update rodina set rc_matky = :new.rc where rodina.rc_matky = '0'; 
	update rodina set rc_otce = :new.rc where rodina.rc_otce = '0' ;
	update manzelstvi set manzelstvi.rc_manzela = :new.rc 
		where manzelstvi.rc_manzela = '0'; 
	update manzelstvi set manzelstvi.rc_manzelky = :new.rc 
		where manzelstvi.rc_manzelky = '0';
	update duchod set duchod.rc_duchodce = :new.rc  
		where duchod.rc_duchodce = '0';
	update invalidni_duchod set invalidni_duchod.rc_duchodce = :new.rc
		where invalidni_duchod.rc_duchodce = '0';
	update invalidni_duchod set invalidni_duchod.rc_duchodce = :new.rc
		where invalidni_duchod.rc_duchodce = '0';
	update zamestnanec set zamestnanec.rc_zamestnance = :new.rc 
		where zamestnanec.rc_zamestnance = '0';
   END IF;
END;
/



CREATE OR REPLACE TRIGGER tr_obcan_pre_up
BEFORE UPDATE ON obcan FOR EACH ROW 
DECLARE
  len NUMBER(2);
  rodc VARCHAR2(10);
  nar DATE;
  narc VARCHAR2(20);
BEGIN
  rodc := :new.rc;
  IF (NOT :new.rc = :old.rc) AND (NOT :new.rc = '0') THEN
    len := length(rodc);
    IF len < 9 OR len > 10 THEN
	RAISE_APPLICATION_ERROR(-20001,'Rodn slo mus mt 9-10 znak.');
    END IF;
    IF SUBSTR(rodc,3,1) = '5' THEN
    	rodc := SUBSTR(rodc,1,2) || '0' || SUBSTR(rodc,4);
    ELSIF SUBSTR(rodc,3,1) = '6' THEN
    	rodc := SUBSTR(rodc,1,2) || '1' || SUBSTR(rodc,4);
    END IF;	
    nar := TO_DATE(SUBSTR(rodc,1,6),'YYMMDD');
    	narc :=to_char(nar);
    IF nar is null THEN
	RAISE_APPLICATION_ERROR(-20001,'Rodn slo je patn zadno.');
    END IF;
  END IF;
   IF not :old.rc = :new.rc THEN
	update bydleni set bydleni.rc = '0' where bydleni.rc = :old.rc;
	update vojak set vojak.rc = '0' where vojak.rc = :old.rc;
	update utvar set utvar.rc_velitele = '0' 
		where rc_velitele = :old.rc;
	update rodina set rodina.rc_potomka = '0' 
		where rodina.rc_potomka = :old.rc;
	update rodina set rc_matky = '0' where rodina.rc_matky = :old.rc; 
	update rodina set rc_otce = '0' where rodina.rc_otce = :old.rc ;
	update manzelstvi set manzelstvi.rc_manzela = '0' 
		where manzelstvi.rc_manzela = :old.rc; 
	update manzelstvi set manzelstvi.rc_manzelky = '0' 
		where manzelstvi.rc_manzelky = :old.rc;
	update duchod set duchod.rc_duchodce = '0'  
		where duchod.rc_duchodce = :old.rc;
	update invalidni_duchod set invalidni_duchod.rc_duchodce = '0'
		where invalidni_duchod.rc_duchodce = :old.rc;
	update starobni_duchod set starobni_duchod.rc_duchodce = '0'
		where starobni_duchod.rc_duchodce = :old.rc;
	update zamestnanec set zamestnanec.rc_zamestnance = '0' 
		where zamestnanec.rc_zamestnance = :old.rc;
   END IF;

END;
/

CREATE OR REPLACE TRIGGER tr_rc_obcan
BEFORE INSERT ON obcan FOR EACH ROW 
DECLARE
  len NUMBER(2);
  rodc VARCHAR2(10);
  nar DATE;
  narc VARCHAR2(20);
BEGIN
  rodc := :new.rc;
  IF (NOT :new.rc = '0') THEN
    len := length(rodc);
    IF len < 9 OR len > 10 THEN
	RAISE_APPLICATION_ERROR(-20001,'Rodn slo mus mt 9-10 znak.');
    END IF;
    IF SUBSTR(rodc,3,1) = '5' THEN
    	rodc := SUBSTR(rodc,1,2) || '0' || SUBSTR(rodc,4);
    ELSIF SUBSTR(rodc,3,1) = '6' THEN
    	rodc := SUBSTR(rodc,1,2) || '1' || SUBSTR(rodc,4);
    END IF;	
    nar := TO_DATE(SUBSTR(rodc,1,6),'YYMMDD');
    	narc :=to_char(nar);
    IF nar is null THEN
	RAISE_APPLICATION_ERROR(-20001,'Rodn slo je patn zadno.');
    END IF;
  END IF;
END;
/

CREATE OR REPLACE TRIGGER tr_ins_bydliste
BEFORE INSERT ON bydliste FOR EACH ROW 
BEGIN
  IF :new.id_bydliste is null THEN
     select id_bydle_seq.nextval 
       into :new.id_bydliste
       from dual;
  END IF;
END;
/

CREATE OR REPLACE TRIGGER zrus_zam
BEFORE DELETE ON zamestnanec
FOR EACH ROW
BEGIN
	DELETE platby WHERE id_pp IN 
		(SELECT id_pp FROM pracovni_pomer pp
		 	 WHERE  pp.id_zamestnance = :OLD.id_zamestnance);
 	DELETE pracovni_pomer WHERE id_zamestnance =:OLD.id_zamestnance;
END;
/


CREATE OR REPLACE TRIGGER duchod_obcan
  after INSERT OR DELETE OR UPDATE OF ma_inv_duchod,ma_star_duchod ON DUCHOD
    FOR EACH ROW
BEGIN
  IF (UPDATING OR INSERTING) THEN
    IF (:NEW.ma_inv_duchod=1 OR :NEW.ma_star_duchod=1) THEN
	UPDATE obcan 
          SET je_duchodce=1
          WHERE RC=:NEW.RC_duchodce;
    ELSE 
	UPDATE obcan 
          SET je_duchodce=0
          WHERE RC=:OLD.RC_duchodce;
    END IF;
  ELSIF DELETING THEN
    UPDATE obcan 
      SET je_duchodce=0
      WHERE RC=:OLD.RC_duchodce;
  END IF;
END;
/



CREATE OR REPLACE TRIGGER zr_voj
BEFORE DELETE ON vojak
FOR EACH ROW
BEGIN
  DELETE FROM slozka 
    WHERE vojenske_cislo = :old.vojenske_cislo;
  UPDATE utvar SET rc_velitele=NULL
    WHERE rc_velitele=:old.rc;
END;

/

CREATE OR REPLACE TRIGGER ed_slozka
BEFORE UPDATE OR INSERT ON SLOZKA
FOR EACH ROW
WHEN (new.datum_vystupu IS NOT NULL)
BEGIN
  IF :new.datum_nastupu > :new.datum_vystupu THEN
     RAISE_APPLICATION_ERROR(-20001, 'Nastup k utvaru byl pozdeji nez odchod');
  END IF;
END;
/


CREATE OR REPLACE TRIGGER zr_manz
AFTER DELETE ON manzelstvi
FOR EACH ROW
DECLARE 
  TMP VARCHAR(20);
  CHG VARCHAR(20);
BEGIN
  SELECT duvod_rozchodu INTO TMP
    FROM manzelstvi
    WHERE rc_manzela = :old.rc_manzela AND datum_svatby =
      (SELECT MAX(datum_svatby) 
       FROM manzelstvi
       WHERE rc_manzela = :old.rc_manzela);

  CHG := NULL;
  IF TMP IS NULL THEN
    CHG := 'Svobodny';
  ELSIF tmp = 'Smrt manzelky' THEN
    CHG := 'Vdovec';
  ELSIF tmp = 'Rozvod' THEN
    CHG := 'Rozvedeny';
  END IF;	    
  UPDATE obcan SET rod_stav = CHG
      WHERE rc = :old.rc_manzela;

  
  SELECT duvod_rozchodu INTO TMP
    FROM manzelstvi
    WHERE rc_manzelky = :old.rc_manzelky AND datum_svatby =
      (SELECT MAX(datum_svatby) 
       FROM manzelstvi
       WHERE rc_manzelky = :old.rc_manzelky);
       
  CHG := NULL;
  IF TMP IS NULL THEN
    CHG := 'Svobodna';
  ELSIF tmp = 'Smrt manzela' THEN
    CHG := 'Vdova';
  ELSIF tmp = 'Rozvod' THEN
    CHG := 'Rozvedena';
  END IF;	    
  
  UPDATE obcan SET rod_stav=CHG
    WHERE rc=:old.rc_manzelky;
END;
/


CREATE OR REPLACE TRIGGER ed_manz
BEFORE INSERT OR UPDATE OF datum_svatby, datum_rozchodu, duvod_rozchodu 
                          ON manzelstvi
FOR EACH ROW
DECLARE
STAV VARCHAR(10);
SVATBA DATE;
BEGIN
    IF :new.datum_rozchodu IS NULL THEN
      UPDATE obcan SET rod_stav='Zenaty'
        WHERE rc=:new.rc_manzela;
      UPDATE obcan SET rod_stav='Vdana'
        WHERE rc=:new.rc_manzelky;
    ELSE
      IF :new.datum_rozchodu < :new.datum_svatby THEN
        RAISE_APPLICATION_ERROR(-20001, 'Svatba pozdeji nez rozchod');
      ELSIF :new.duvod_rozchodu IS NULL THEN
        RAISE_APPLICATION_ERROR(-20003, 'Nespecifikovan duvod rozchodu');
      END IF;
      IF :new.duvod_rozchodu = 'Smrt manzela' THEN
        UPDATE obcan SET rod_stav = 'Vdova'
          WHERE rc=:new.rc_manzelky;
      ELSIF :new.duvod_rozchodu = 'Smrt manzelky' THEN
        UPDATE obcan SET rod_stav = 'Vdovec'
          WHERE rc=:new.rc_manzela;
      ELSE
        UPDATE obcan SET rod_stav='Rozvedeny'
          WHERE rc=:new.rc_manzela;
        UPDATE obcan SET rod_stav='Rozvedena'
          WHERE rc=:new.rc_manzelky;
      END IF;
    END IF;
END;
/

